#[repr(transparent)]pub struct Dma0ReqEnable1Set(pub u32);Expand description
DMA0 Request Enable1
Tuple Fields
0: u32Implementations
Sourceimpl Dma0ReqEnable1Set
impl Dma0ReqEnable1Set
Sourcepub const fn req32_en0(&self) -> bool
pub const fn req32_en0(&self) -> bool
Writing a 1 to REQ32_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req32_en0(&mut self, val: bool)
pub const fn set_req32_en0(&mut self, val: bool)
Writing a 1 to REQ32_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req33_en0(&self) -> bool
pub const fn req33_en0(&self) -> bool
Writing a 1 to REQ33_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req33_en0(&mut self, val: bool)
pub const fn set_req33_en0(&mut self, val: bool)
Writing a 1 to REQ33_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req34_en0(&self) -> bool
pub const fn req34_en0(&self) -> bool
Writing a 1 to REQ34_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req34_en0(&mut self, val: bool)
pub const fn set_req34_en0(&mut self, val: bool)
Writing a 1 to REQ34_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req35_en0(&self) -> bool
pub const fn req35_en0(&self) -> bool
Writing a 1 to REQ35_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req35_en0(&mut self, val: bool)
pub const fn set_req35_en0(&mut self, val: bool)
Writing a 1 to REQ35_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req36_en0(&self) -> bool
pub const fn req36_en0(&self) -> bool
Writing a 1 to REQ36_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req36_en0(&mut self, val: bool)
pub const fn set_req36_en0(&mut self, val: bool)
Writing a 1 to REQ36_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req37_en0(&self) -> bool
pub const fn req37_en0(&self) -> bool
Writing a 1 to REQ37_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req37_en0(&mut self, val: bool)
pub const fn set_req37_en0(&mut self, val: bool)
Writing a 1 to REQ37_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req38_en0(&self) -> bool
pub const fn req38_en0(&self) -> bool
Writing a 1 to REQ38_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req38_en0(&mut self, val: bool)
pub const fn set_req38_en0(&mut self, val: bool)
Writing a 1 to REQ38_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req39_en0(&self) -> bool
pub const fn req39_en0(&self) -> bool
Writing a 1 to REQ39_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req39_en0(&mut self, val: bool)
pub const fn set_req39_en0(&mut self, val: bool)
Writing a 1 to REQ39_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req40_en0(&self) -> bool
pub const fn req40_en0(&self) -> bool
Writing a 1 to REQ40_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req40_en0(&mut self, val: bool)
pub const fn set_req40_en0(&mut self, val: bool)
Writing a 1 to REQ40_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req41_en0(&self) -> bool
pub const fn req41_en0(&self) -> bool
Writing a 1 to REQ41_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req41_en0(&mut self, val: bool)
pub const fn set_req41_en0(&mut self, val: bool)
Writing a 1 to REQ41_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req42_en0(&self) -> bool
pub const fn req42_en0(&self) -> bool
Writing a 1 to REQ42_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req42_en0(&mut self, val: bool)
pub const fn set_req42_en0(&mut self, val: bool)
Writing a 1 to REQ42_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req43_en0(&self) -> bool
pub const fn req43_en0(&self) -> bool
Writing a 1 to REQ43_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req43_en0(&mut self, val: bool)
pub const fn set_req43_en0(&mut self, val: bool)
Writing a 1 to REQ43_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req44_en0(&self) -> bool
pub const fn req44_en0(&self) -> bool
Writing a 1 to REQ44_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req44_en0(&mut self, val: bool)
pub const fn set_req44_en0(&mut self, val: bool)
Writing a 1 to REQ44_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req45_en0(&self) -> bool
pub const fn req45_en0(&self) -> bool
Writing a 1 to REQ45_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req45_en0(&mut self, val: bool)
pub const fn set_req45_en0(&mut self, val: bool)
Writing a 1 to REQ45_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req46_en0(&self) -> bool
pub const fn req46_en0(&self) -> bool
Writing a 1 to REQ46_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req46_en0(&mut self, val: bool)
pub const fn set_req46_en0(&mut self, val: bool)
Writing a 1 to REQ46_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req47_en0(&self) -> bool
pub const fn req47_en0(&self) -> bool
Writing a 1 to REQ47_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req47_en0(&mut self, val: bool)
pub const fn set_req47_en0(&mut self, val: bool)
Writing a 1 to REQ47_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req48_en0(&self) -> bool
pub const fn req48_en0(&self) -> bool
Writing a 1 to REQ48_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req48_en0(&mut self, val: bool)
pub const fn set_req48_en0(&mut self, val: bool)
Writing a 1 to REQ48_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req49_en0(&self) -> bool
pub const fn req49_en0(&self) -> bool
Writing a 1 to REQ49_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req49_en0(&mut self, val: bool)
pub const fn set_req49_en0(&mut self, val: bool)
Writing a 1 to REQ49_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req50_en0(&self) -> bool
pub const fn req50_en0(&self) -> bool
Writing a 1 to REQ50_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req50_en0(&mut self, val: bool)
pub const fn set_req50_en0(&mut self, val: bool)
Writing a 1 to REQ50_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req51_en0(&self) -> bool
pub const fn req51_en0(&self) -> bool
Writing a 1 to REQ51_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req51_en0(&mut self, val: bool)
pub const fn set_req51_en0(&mut self, val: bool)
Writing a 1 to REQ51_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req52_en0(&self) -> bool
pub const fn req52_en0(&self) -> bool
Writing a 1 to REQ52_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req52_en0(&mut self, val: bool)
pub const fn set_req52_en0(&mut self, val: bool)
Writing a 1 to REQ52_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req53_en0(&self) -> bool
pub const fn req53_en0(&self) -> bool
Writing a 1 to REQ53_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req53_en0(&mut self, val: bool)
pub const fn set_req53_en0(&mut self, val: bool)
Writing a 1 to REQ53_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req54_en0(&self) -> bool
pub const fn req54_en0(&self) -> bool
Writing a 1 to REQ54_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req54_en0(&mut self, val: bool)
pub const fn set_req54_en0(&mut self, val: bool)
Writing a 1 to REQ54_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req57_en0(&self) -> bool
pub const fn req57_en0(&self) -> bool
Writing a 1 to REQ57_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req57_en0(&mut self, val: bool)
pub const fn set_req57_en0(&mut self, val: bool)
Writing a 1 to REQ57_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req58_en0(&self) -> bool
pub const fn req58_en0(&self) -> bool
Writing a 1 to REQ58_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req58_en0(&mut self, val: bool)
pub const fn set_req58_en0(&mut self, val: bool)
Writing a 1 to REQ58_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req59_en0(&self) -> bool
pub const fn req59_en0(&self) -> bool
Writing a 1 to REQ59_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req59_en0(&mut self, val: bool)
pub const fn set_req59_en0(&mut self, val: bool)
Writing a 1 to REQ59_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req60_en0(&self) -> bool
pub const fn req60_en0(&self) -> bool
Writing a 1 to REQ60_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req60_en0(&mut self, val: bool)
pub const fn set_req60_en0(&mut self, val: bool)
Writing a 1 to REQ60_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req61_en0(&self) -> bool
pub const fn req61_en0(&self) -> bool
Writing a 1 to REQ61_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req61_en0(&mut self, val: bool)
pub const fn set_req61_en0(&mut self, val: bool)
Writing a 1 to REQ61_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req62_en0(&self) -> bool
pub const fn req62_en0(&self) -> bool
Writing a 1 to REQ62_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req62_en0(&mut self, val: bool)
pub const fn set_req62_en0(&mut self, val: bool)
Writing a 1 to REQ62_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn req63_en0(&self) -> bool
pub const fn req63_en0(&self) -> bool
Writing a 1 to REQ63_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.
Sourcepub const fn set_req63_en0(&mut self, val: bool)
pub const fn set_req63_en0(&mut self, val: bool)
Writing a 1 to REQ63_EN0 in this register sets the corresponding bit in DMA0_REQ_ENABLE1.