nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Dma0ReqEnable3Clr

Struct Dma0ReqEnable3Clr 

#[repr(transparent)]
pub struct Dma0ReqEnable3Clr(pub u32);
DMA0 Request Enable3

Tuple Fields

0: u32

Implementations

Source

impl Dma0ReqEnable3Clr

pub const fn req96_en0(&self) -> bool

Writing a 1 to REQ96_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req96_en0(&mut self, val: bool)

Writing a 1 to REQ96_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req97_en0(&self) -> bool

Writing a 1 to REQ97_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req97_en0(&mut self, val: bool)

Writing a 1 to REQ97_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req98_en0(&self) -> bool

Writing a 1 to REQ98_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req98_en0(&mut self, val: bool)

Writing a 1 to REQ98_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req99_en0(&self) -> bool

Writing a 1 to REQ99_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req99_en0(&mut self, val: bool)

Writing a 1 to REQ99_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req100_en0(&self) -> bool

Writing a 1 to REQ100_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req100_en0(&mut self, val: bool)

Writing a 1 to REQ100_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req101_en0(&self) -> bool

Writing a 1 to REQ101_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req101_en0(&mut self, val: bool)

Writing a 1 to REQ101_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req102_en0(&self) -> bool

Writing a 1 to REQ102_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req102_en0(&mut self, val: bool)

Writing a 1 to REQ102_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req103_en0(&self) -> bool

Writing a 1 to REQ103_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req103_en0(&mut self, val: bool)

Writing a 1 to REQ103_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req104_en0(&self) -> bool

Writing a 1 to REQ104_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req104_en0(&mut self, val: bool)

Writing a 1 to REQ104_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req105_en0(&self) -> bool

Writing a 1 to REQ105_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req105_en0(&mut self, val: bool)

Writing a 1 to REQ105_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req106_en0(&self) -> bool

Writing a 1 to REQ106_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req106_en0(&mut self, val: bool)

Writing a 1 to REQ106_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req107_en0(&self) -> bool

Writing a 1 to REQ107_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req107_en0(&mut self, val: bool)

Writing a 1 to REQ107_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req108_en0(&self) -> bool

Writing a 1 to REQ108_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req108_en0(&mut self, val: bool)

Writing a 1 to REQ108_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req109_en0(&self) -> bool

Writing a 1 to REQ109_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req109_en0(&mut self, val: bool)

Writing a 1 to REQ109_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req110_en0(&self) -> bool

Writing a 1 to REQ110_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req110_en0(&mut self, val: bool)

Writing a 1 to REQ110_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req111_en0(&self) -> bool

Writing a 1 to REQ111_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req111_en0(&mut self, val: bool)

Writing a 1 to REQ111_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req112_en0(&self) -> bool

Writing a 1 to REQ112_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req112_en0(&mut self, val: bool)

Writing a 1 to REQ112_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req113_en0(&self) -> bool

Writing a 1 to REQ113_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req113_en0(&mut self, val: bool)

Writing a 1 to REQ113_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req114_en0(&self) -> bool

Writing a 1 to REQ114_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req114_en0(&mut self, val: bool)

Writing a 1 to REQ114_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req115_en0(&self) -> bool

Writing a 1 to REQ115_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req115_en0(&mut self, val: bool)

Writing a 1 to REQ115_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req116_en0(&self) -> bool

Writing a 1 to REQ116_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req116_en0(&mut self, val: bool)

Writing a 1 to REQ116_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req117_en0(&self) -> bool

Writing a 1 to REQ117_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req117_en0(&mut self, val: bool)

Writing a 1 to REQ117_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req118_en0(&self) -> bool

Writing a 1 to REQ118_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req118_en0(&mut self, val: bool)

Writing a 1 to REQ118_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req119_en0(&self) -> bool

Writing a 1 to REQ119_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req119_en0(&mut self, val: bool)

Writing a 1 to REQ119_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req120_en0(&self) -> bool

Writing a 1 to REQ120_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req120_en0(&mut self, val: bool)

Writing a 1 to REQ120_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn req121_en0(&self) -> bool

Writing a 1 to REQ121_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3

pub const fn set_req121_en0(&mut self, val: bool)

Writing a 1 to REQ121_EN0 in this register clears the corresponding bit in DMA0_REQ_ENABLE3