nxp-pac

Crates

git

Versions

mcxn947_cm33_core0

Flavors

Dma1ReqEnable1Set

Struct Dma1ReqEnable1Set 

#[repr(transparent)]
pub struct Dma1ReqEnable1Set(pub u32);
DMA1 Request Enable1

Tuple Fields

0: u32

Implementations

Source

impl Dma1ReqEnable1Set

pub const fn req32_en1(&self) -> bool

Writing a 1 to REQ32_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req32_en1(&mut self, val: bool)

Writing a 1 to REQ32_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req33_en1(&self) -> bool

Writing a 1 to REQ33_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req33_en1(&mut self, val: bool)

Writing a 1 to REQ33_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req34_en1(&self) -> bool

Writing a 1 to REQ34_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req34_en1(&mut self, val: bool)

Writing a 1 to REQ34_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req35_en1(&self) -> bool

Writing a 1 to REQ35_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req35_en1(&mut self, val: bool)

Writing a 1 to REQ35_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req36_en1(&self) -> bool

Writing a 1 to REQ36_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req36_en1(&mut self, val: bool)

Writing a 1 to REQ36_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req37_en1(&self) -> bool

Writing a 1 to REQ37_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req37_en1(&mut self, val: bool)

Writing a 1 to REQ37_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req38_en1(&self) -> bool

Writing a 1 to REQ38_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req38_en1(&mut self, val: bool)

Writing a 1 to REQ38_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req39_en1(&self) -> bool

Writing a 1 to REQ39_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req39_en1(&mut self, val: bool)

Writing a 1 to REQ39_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req40_en1(&self) -> bool

Writing a 1 to REQ40_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req40_en1(&mut self, val: bool)

Writing a 1 to REQ40_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req41_en1(&self) -> bool

Writing a 1 to REQ41_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req41_en1(&mut self, val: bool)

Writing a 1 to REQ41_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req42_en1(&self) -> bool

Writing a 1 to REQ42_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req42_en1(&mut self, val: bool)

Writing a 1 to REQ42_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req43_en1(&self) -> bool

Writing a 1 to REQ43_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req43_en1(&mut self, val: bool)

Writing a 1 to REQ43_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req44_en1(&self) -> bool

Writing a 1 to REQ44_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req44_en1(&mut self, val: bool)

Writing a 1 to REQ44_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req45_en1(&self) -> bool

Writing a 1 to REQ45_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req45_en1(&mut self, val: bool)

Writing a 1 to REQ45_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req46_en1(&self) -> bool

Writing a 1 to REQ46_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req46_en1(&mut self, val: bool)

Writing a 1 to REQ46_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req47_en1(&self) -> bool

Writing a 1 to REQ47_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req47_en1(&mut self, val: bool)

Writing a 1 to REQ47_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req48_en1(&self) -> bool

Writing a 1 to REQ48_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req48_en1(&mut self, val: bool)

Writing a 1 to REQ48_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req49_en1(&self) -> bool

Writing a 1 to REQ49_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req49_en1(&mut self, val: bool)

Writing a 1 to REQ49_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req50_en1(&self) -> bool

Writing a 1 to REQ50_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req50_en1(&mut self, val: bool)

Writing a 1 to REQ50_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req51_en1(&self) -> bool

Writing a 1 to REQ51_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req51_en1(&mut self, val: bool)

Writing a 1 to REQ51_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req52_en1(&self) -> bool

Writing a 1 to REQ52_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req52_en1(&mut self, val: bool)

Writing a 1 to REQ52_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req53_en1(&self) -> bool

Writing a 1 to REQ53_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req53_en1(&mut self, val: bool)

Writing a 1 to REQ53_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req54_en1(&self) -> bool

Writing a 1 to REQ54_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req54_en1(&mut self, val: bool)

Writing a 1 to REQ54_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req57_en1(&self) -> bool

Writing a 1 to REQ57_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req57_en1(&mut self, val: bool)

Writing a 1 to REQ57_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req58_en1(&self) -> bool

Writing a 1 to REQ58_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req58_en1(&mut self, val: bool)

Writing a 1 to REQ58_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req59_en1(&self) -> bool

Writing a 1 to REQ59_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req59_en1(&mut self, val: bool)

Writing a 1 to REQ59_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req60_en1(&self) -> bool

Writing a 1 to REQ60_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req60_en1(&mut self, val: bool)

Writing a 1 to REQ60_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req61_en1(&self) -> bool

Writing a 1 to REQ61_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req61_en1(&mut self, val: bool)

Writing a 1 to REQ61_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req62_en1(&self) -> bool

Writing a 1 to REQ62_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req62_en1(&mut self, val: bool)

Writing a 1 to REQ62_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn req63_en1(&self) -> bool

Writing a 1 to REQ63_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.

pub const fn set_req63_en1(&mut self, val: bool)

Writing a 1 to REQ63_EN1 in this register sets the corresponding bit in DMA1_REQ_ENABLE1.